@@ -16,7 +16,7 @@ use XML::LibXML::PrettyPrint;
 
 use OTRS::OPM::Maker -command;
 
-our $VERSION = 1.09;
+our $VERSION = 1.10;
 
 sub abstract {
     return "build sopm file based on metadata";
@@ -106,10 +106,11 @@ sub execute {
     {
         my @files = File::Find::Rule->file->in( '.' );
 
-        # remove "hidden" files from list;
+        # remove "hidden" files from list; and do not list .sopm
         @files = grep{ 
             ( substr( $_, 0, 1 ) ne '.' ) &&
-            $_ !~ m{[\\/]\.} 
+            $_ !~ m{[\\/]\.} &&
+            $_ ne $json->{name} . '.sopm'
         }sort @files;
 
         push @xml_parts, 
@@ -188,10 +189,6 @@ sub execute {
         $code->{type} = 'Code' . $code->{type};
         push @xml_parts, _CodeTemplate( $code->{type}, $code->{version}, $code->{function} || $code->{type} );
     }
-
-    for my $intro ( @{ $json->{intro} || [] } ) {
-        push @xml_parts, _IntroTemplate( $intro );
-    }
     
     my $xml = sprintf qq~<?xml version="1.0" encoding="utf-8" ?>
 <otrs_package version="1.0">
@@ -206,24 +203,11 @@ sub execute {
     $json->{version},
     join( "\n", @xml_parts );
 
-    my $fh = IO::File->new( $name . '.sopm', 'w' );
+    my $fh = IO::File->new( $name . '.sopm', 'w' ) or die $!;
     $fh->print( $xml );
     $fh->close;
 }
 
-sub _IntroTemplate {
-    my ($intro) = @_;
-
-    my $version = $intro->{version} ? ' Version="' . $intro->{version} . '"' : '';
-    my $type    = $intro->{type};
-    my $text    = ref $intro->{text} ? join( "\n", @{ $intro->{text} } ) : $intro->{text};
-
-    return qq~    <Intro$type Type="post"$version><![CDATA[
-            $text
-        </Intro$type>
-    ~;
-}
-
 sub _CodeTemplate {
     my ($type, $version, $function) = @_;
 
@@ -377,7 +361,7 @@ OTRS::OPM::Maker::Command::sopm - Build .sopm file based on metadata
 
 =head1 VERSION
 
-version 1.09
+version 1.1
 
 =head1 CONFIGURATION
 
